@@ -39,6 +39,8 @@ from torch.optim.lr_scheduler import (
 
 from torchvision.transforms.functional import to_tensor as im2tensor
 
+from loguru import logger
+
 # Soft imports
 from icevision.soft_dependencies import SoftDependencies
 
@@ -48,6 +50,9 @@ if SoftDependencies.fastai:
 if SoftDependencies.pytorch_lightning:
     import pytorch_lightning as pl
 
+if SoftDependencies.wandb:
+    import wandb
+
 
 # TODO: Stop importing partial from fastcore and move this to utils
 class partial:
